@@ -89,8 +89,9 @@ def multcompCatplot(**kwargs):
         pointArgs = kwargs["pointArgs"]
         del kwargs["pointArgs"]
     elif "pointSize" in kwargs:
-        kwargs["pointArgs"] = {"size": kwargs["pointSize"]}
+        pointArgs = {"size": kwargs["pointSize"]}
         del kwargs["pointSize"]
+        del kwargs["pointArgs"]
     else:
         pointArgs = {}
     g = sns.catplot(**kwargs)
